module.exports = defineTest({
	description: 'deoptimizes "this" for accessors triggered by for-in loops'
});
